Module bch

Module bch 

Encoding and decoding of the (63, 16, 23) BCH code described by P25.

These algorithms are derived from Coding Theory and Cryptography: The Essentials, Hankerson, Hoffman, et al, 2000.

Functions

decode
Try to decode the given 64-bit word to the nearest codeword, correcting up to 11 bit errors.
encode
Encode the given 16 data bits into a 64-bit codeword.