Module cyclic

Module cyclic 

Encoding and decoding of the (16, 8, 5) shortened cyclic code described by P25.

The key information that this code is shortened from a (17, 8, 5) code came from “Standard APCO25 Physical Layer of the Radio Transmission Chain”, Simon, 2014.

Functions

decode
Try to decode the given 16-bit word to the nearest codeword, correcting up to 2 errors.
encode
Encode the given 8 data bits into a 16-bit codeword.